@@ -6,37 +6,38 @@ source
 from collections import namedtuple
 
 # Named Tuple to representing the properties of a Lambda Function
-Function = namedtuple("Function", [
+_Function = namedtuple("Function", [
     # Function name or logical ID
     "name",
 
-    # Runtime/language
-    "runtime",
-
-    # Memory in MBs
-    "memory",
-
-    # Function Timeout in seconds
-    "timeout",
-
-    # Name of the handler
-    "handler",
-
-    # Description of the function
-    "description",
-
-    # Path to the code. This could be a S3 URI or local path or a dictionary of S3 Bucket, Key, Version
-    "codeuri",
-
-    # Environment variables. This is a dictionary with one key called Variables inside it. This contains the definition
-    # of environment variables
-    "environment",
-
-    # Lambda Execution IAM Role ARN. In the future, this can be used by Local Lambda runtime to assume the IAM role
-    # to get credentials to run the container with. This gives a much higher fidelity simulation of cloud Lambda.
-    "rolearn"
+    # Function all properties
+    "properties"
 ])
 
+class Function(_Function):
+    @property
+    def codeuri(self):
+        return self.properties.get("CodeUri")
+
+    @property
+    def handler(self):
+        return self.properties.get("Handler")
+
+    @property
+    def timeout(self):
+        return self.properties.get("Timeout")
+
+    @property
+    def environment(self):
+        return self.properties.get("Environment")
+
+    @property
+    def memory(self):
+        return self.properties.get("Memory")
+
+    @property
+    def runtime(self):
+        return self.properties.get("Runtime")
 
 class FunctionProvider(object):
     """
@@ -61,6 +62,55 @@ class FunctionProvider(object):
         raise NotImplementedError("not implemented")
 
 
+# Named Tuple to representing the properties of a Lambda Function
+Layer = namedtuple("Layer", [
+    # str Layer name or logical ID
+    "name",
+
+    # str layer file dir
+    "layer_uri",
+
+    # array of str 
+    "compatible_runtimes",
+
+    # str
+    "description",
+
+    # str
+    "license_info"
+])
+
+class LayerProvider(object):
+    """
+    Abstract base class of the layer provider.
+    """
+
+    def get(self, name):
+        """
+        Given name of the layer, this method must return the layer object
+
+        :param string name: Name of the layer
+        :return layer: namedtuple containing the layer information
+        """
+        raise NotImplementedError("not implemented")
+
+    def get_all(self):
+        """
+        Yields all the layers available in the provider.
+
+        :yields layer: namedtuple containing the layer information
+        """
+        raise NotImplementedError("not implemented")
+    
+    def deploy(self, name):
+        """
+        Yields all the layers available in the provider.
+
+        :yields layer: namedtuple containing the layer information
+        """
+        raise NotImplementedError("not implemented")
+
+
 _ApiTuple = namedtuple("Api", [
 
     # String. Path that this API serves. Ex: /foo, /bar/baz
