@@ -133,10 +133,7 @@ class CfcClient(bce_base_client.BceBaseClient):
         """
         return self.invocations(function_name, invocation_type, log_type, body, qualifier, config)
 
-    def create_function(self, function_name, description=None, environment=None,
-                        handler=None, memory_size=128, region='bj',
-                        zip_file=None, publish=False, run_time='python2',
-                        timeout=3, dry_run=False, code_zip_file=None, config=None):
+    def create_function(self, function_name, zip_file, data, config=None):
         """
         Create cfc function
 
@@ -165,48 +162,20 @@ class CfcClient(bce_base_client.BceBaseClient):
 
         :param config: None
         :type config: baidubce.BceClientConfiguration
-
-        :param publish  This boolean parameter can be used to request CFC to create the CFC function and publish
-                        a version as an atomic operation.
-        :type publish: boolean
-
-        :param run_time: python2 | nodejs6.11
-        :type run_time: string
-
-        :param timeout: 1-300 The default is 3 seconds.
-        :type timeout: int
-
+        
         :param code_zip_file: the file path of the zipped code.
         :type code_zip_file: string
 
         :return:
         :rtype: baidubce.bce_response.BceResponse
         """
-        if environment is None:
-            environment = {}
-        data = {
-            'Code': {
-                'Publish': publish,
-                'DryRun': dry_run
-            },
-            'Description': description,
-            'Region': region,
-            'Timeout': timeout,
-            'FunctionName': function_name,
-            'Handler': handler,
-            'Runtime': run_time,
-            'MemorySize': memory_size,
-            'Environment': {
-                'Variables': environment
-            }
-        }
-        if code_zip_file:
-            code_file = open(code_zip_file, 'rb')
-            code = code_file.read()
-            code_base64 = base64.b64encode(code).decode('utf-8')
-            data['Code']['ZipFile'] = code_base64
-        else:
-            data['Code']['ZipFile'] = zip_file
+
+        data['FunctionName'] = function_name
+        data['Code'] = {
+            'Publish': data.get('Publish', False),
+            'DryRun': data.get('DryRun', False),
+            'ZipFile': zip_file,
+        } 
         params = {}
         return self._send_request(
             http_methods.POST,
@@ -399,46 +368,21 @@ class CfcClient(bce_base_client.BceBaseClient):
             params={},
             config=config)
 
-    def update_function_configuration(self, function_name, description=None, environment=None,
-                                      handler=None, run_time=None,
-                                      timeout=None, config=None):
+    def update_function_configuration(self, function_name, data, config=None):
         """
         update_function_configuration
         :param function_name  (required)
         :type function_name string
 
-        :param description - A short, user-defined function description. Minimum length of 0. Maximum length of 256.
-        :type description string
-
-        :param environment environment's configuration settings.
-        :type environment String to string map, [a-zA-Z]([a-zA-Z0-9_])+
-
-        :param handler  (required) Maximum length of 128. [^\s]+
-        :type handler string
-
-        :param run_time: python2 | nodejs6.11
-        :type run_time: string
-
-        :param timeout: 1-300 The default is 3 seconds.
-        :type timeout: int
-
+        :param data (required)
+        :type data object
+    
         :param config: None
         :type config: baidubce.BceClientConfiguration
 
         :return:
         :rtype: baidubce.bce_response.BceResponse
         """
-        data = {}
-        if description is not None:
-            data["Description"] = description
-        if environment is not None:
-            data["Environment"] = {"Variables": environment}
-        if handler is not None:
-            data["Handler"] = handler
-        if run_time is not None:
-            data["Runtime"] = run_time
-        if timeout is not None:
-            data["Timeout"] = timeout
         return self._send_request(
             http_methods.PUT,
             '/functions/' + function_name + '/configuration',
@@ -876,6 +820,45 @@ class CfcClient(bce_base_client.BceBaseClient):
             params=params,
             config=config)
 
+    def publish_layer(self, layer_name, content=None, description=None,
+            license_info=None, compatible_runtimes=None, config=None):
+        """
+        publish_layer
+        :param layer_name  (required) The cfc layer name
+        :type layer_name string       
+
+        :param content (required) layer base64 object or bos bucket file path
+        :type content {"BosBucket":"string", "BosObject": "string", "ZipFile": "string"}
+
+        :param description   Description of the layer.
+        :type description string
+
+        :param license_info   license information of depencies.
+        :type license_info string
+
+        :param compatible_runtimes (required) cfc supported runtimes
+        :type compatible_runtimes array of string
+
+        :param config: None
+        :type config: baidubce.BceClientConfiguration        
+
+        :return:
+        :rtype: baidubce.bce_response.BceResponse
+        """
+        data = {
+            "Description": description,
+            "LicenseInfo": license_info,
+            "CompatibleRuntimes": compatible_runtimes,
+            "Content": content,            
+        }
+
+        return self._send_request(
+            http_methods.POST,
+            '/layers/' + layer_name + "/versions",
+            body=json.dumps(data),
+            params={},
+            config=config)
+
     @staticmethod
     def _encode_function_name(self, function_name):
         return ''
